@@ -164,7 +164,7 @@ sub _setup_response
 {
   my ($s, $response_code) = @_;
   
-  $response_code = 200 if $response_code eq '0';
+  $response_code = 200 if ($response_code || 0) eq '0';
   my $response = HTTP::Response->new( $response_code );
   
   # XXX: Sometimes this dies with 'HTTP::Message requires bytes' or similar:
